# Security Policy

## Supported Versions

Use this section to tell people about which versions of your project are
currently being supported with security updates.

| Version | Supported          |
| ------- | ------------------ |
| 1.0.x   | :white_check_mark: |
| < 1.0   | :x:                |

## Reporting a Vulnerability

We take the security of this project seriously. If you have found a vulnerability, please report it to us immediately.

### How to Report

Please do **not** report security vulnerabilities through public GitHub issues, discussions, or pull requests.

Instead, please send an email to [vcfmerger mail](mailto:faisalmoshiur+vcfmerger@gmail.com).

Please include as much information as possible to help us reproduce and fix the issue, including:
- Steps to reproduce the vulnerability
- Relevant code or configuration
- Any specific environment details

### Response Timeline

We will try to acknowledge your report within 48 hours. We will keep you updated on our progress as we investigate and fix the issue.

### Public Disclosure

We ask that you give us a reasonable amount of time to fix the vulnerability before disclosing it publicly. We will coordinate with you on the timing of the disclosure.

Thank you for helping keep this project safe!
